Core Module
===========

This module contains the core classes for video and audio handling.

.. autoclass:: fmusvid.core.video.Video
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: fmusvid.core.frame.Frame
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: fmusvid.core.audio.Audio
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: fmusvid.core.audio_utils
   :members:
   :undoc-members:

.. autoclass:: fmusvid.core.stream.Stream
   :members:
   :undoc-members:
   :show-inheritance:
